@@ -95,7 +95,12 @@ static const char *role_names [] =
   "unknown",
   "viewport",
   "window",
-
+  NULL,
+  "header",
+  "fooler",
+  "paragraph",
+  "ruler",
+  "application"
 };
 
 #define MAX_ROLES (sizeof (role_names) / sizeof (char *))
@@ -177,7 +182,11 @@ cspi_init_role_table (AccessibleRole *role_table)
   role_table [Accessibility_ROLE_VIEWPORT] = SPI_ROLE_VIEWPORT;
   role_table [Accessibility_ROLE_WINDOW] = SPI_ROLE_WINDOW;
   role_table [Accessibility_ROLE_EXTENDED] = SPI_ROLE_EXTENDED;
-  role_table [Accessibility_ROLE_LAST_DEFINED] = SPI_ROLE_EXTENDED;
+  role_table [Accessibility_ROLE_HEADER] = SPI_ROLE_HEADER;
+  role_table [Accessibility_ROLE_FOOTER] = SPI_ROLE_FOOTER;
+  role_table [Accessibility_ROLE_PARAGRAPH] = SPI_ROLE_PARAGRAPH;
+  role_table [Accessibility_ROLE_RULER] = SPI_ROLE_RULER;
+  role_table [Accessibility_ROLE_APPLICATION] = SPI_ROLE_APPLICATION;
 
   return TRUE;
 }
@@ -240,6 +249,7 @@ init_state_table (Accessibility_StateType *state_table)
   state_table[SPI_STATE_TRANSIENT] = Accessibility_STATE_TRANSIENT;
   state_table[SPI_STATE_VERTICAL] = Accessibility_STATE_VERTICAL;
   state_table[SPI_STATE_VISIBLE] = Accessibility_STATE_VISIBLE;
+  state_table[SPI_STATE_MANAGES_DESCENDANTS] = Accessibility_STATE_MANAGES_DESCENDANTS;
 
   return TRUE;
 }
@@ -277,7 +287,7 @@ spi_state_type_from_accessible_state (AccessibleState type)
 char *
 AccessibleRole_getName (AccessibleRole role)
 {
-  if (role < MAX_ROLES)
+  if (role < MAX_ROLES && role_names [(int) role])
     {
       return CORBA_string_dup (role_names [(int) role]);
     }
@@ -510,7 +520,7 @@ Accessible_getRelationSet (Accessible *obj)
 AccessibleRole
 Accessible_getRole (Accessible *obj)
 {
-  AccessibleRole retval;
+  Accessibility_Role retval;
 
   cspi_return_val_if_fail (obj != NULL, SPI_ROLE_INVALID);
 
