@@ -2,7 +2,8 @@
  * AT-SPI - Assistive Technology Service Provider Interface
  * (Gnome Accessibility Project; http://developer.gnome.org/projects/gap)
  *
- * Copyright 2001 Sun Microsystems Inc.
+ * Copyright 2001, 2002 Sun Microsystems Inc.,
+ * Copyright 2001, 2002 Ximian, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -242,6 +243,25 @@ cspi_object_return (Accessible *accessible)
     }
 }
 
+Accessible *
+cspi_object_take (CORBA_Object corba_object)
+{
+  Accessible *accessible;
+  accessible = cspi_object_borrow (corba_object);
+  cspi_object_ref (accessible->objref);
+  /* 
+   * if the remote object is dead, 
+   * cspi_object_return will throw an exception. 
+   */
+  cspi_object_return (accessible->objref);
+  if (cspi_exception ()) 
+    {
+      cspi_object_unref (accessible->objref);
+      accessible = NULL;
+    }
+  return accessible;
+}
+
 void
 cspi_object_ref (Accessible *accessible)
 {
@@ -391,8 +411,8 @@ report_leaked_ref (gpointer key, gpointer val, gpointer user_data)
       role = NULL;
     }
 
-  fprintf (stderr, "leaked %d references to object %s, role %s\n",
-	   a->ref_count, name ? name : "<?>", role ? role : "<?>");
+  fprintf (stderr, "leaked %d references to object %s, role %s %p\n",
+	   a->ref_count, name ? name : "<?>", role ? role : "<?>", a);
 
   SPI_freeString (name);
 }
