@@ -2,7 +2,8 @@
  * AT-SPI - Assistive Technology Service Provider Interface
  * (Gnome Accessibility Project; http://developer.gnome.org/projects/gap)
  *
- * Copyright 2001 Sun Microsystems Inc.
+ * Copyright 2001, 2002 Sun Microsystems Inc.,
+ * Copyright 2001, 2002 Ximian, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -39,19 +40,20 @@ spi_init_state_type_tables (void)
   if (accessible_state_types || atk_state_types)
     return FALSE;
   if (!accessible_state_types)
-    accessible_state_types = g_new (Accessibility_StateType, Accessibility_STATE_LAST_DEFINED);
+    accessible_state_types = g_new (Accessibility_StateType, ATK_STATE_LAST_DEFINED);
   if (!atk_state_types)
-    atk_state_types = g_new (AtkStateType, ATK_STATE_LAST_DEFINED);
+    atk_state_types = g_new (AtkStateType, Accessibility_STATE_LAST_DEFINED);
   g_return_val_if_fail (accessible_state_types, FALSE);
   g_return_val_if_fail (atk_state_types, FALSE);
   
-  accessible_state_types = g_new (Accessibility_StateType, ATK_STATE_LAST_DEFINED);
-  atk_state_types = g_new (AtkStateType, ATK_STATE_LAST_DEFINED);
-
-  for (i = 0; i < ATK_STATE_LAST_DEFINED; i++)
+  for (i = 0; i < Accessibility_STATE_LAST_DEFINED; i++)
     {
       atk_state_types[i] = ATK_STATE_INVALID;
-      accessible_state_types[i] = Accessibility_STATE_INVALID;
+    }
+
+  for (i=0; i < ATK_STATE_LAST_DEFINED; i++)
+    {
+      accessible_state_types[i] = Accessibility_STATE_INVALID;	
     }
 
   accessible_state_types[ATK_STATE_ACTIVE] = Accessibility_STATE_ACTIVE;
@@ -110,6 +112,8 @@ spi_init_state_type_tables (void)
   atk_state_types[Accessibility_STATE_VERTICAL] = ATK_STATE_VERTICAL;
   accessible_state_types[ATK_STATE_VISIBLE] = Accessibility_STATE_VISIBLE;
   atk_state_types[Accessibility_STATE_VISIBLE] = ATK_STATE_VISIBLE;
+  accessible_state_types[ATK_STATE_MANAGES_DESCENDANTS] = Accessibility_STATE_MANAGES_DESCENDANTS;
+  atk_state_types[Accessibility_STATE_MANAGES_DESCENDANTS] = ATK_STATE_MANAGES_DESCENDANTS;
 
   return TRUE;
 }
@@ -166,8 +170,7 @@ impl_contains (PortableServer_Servant servant,
   AtkStateSet *set = atk_state_set_from_servant (servant);
 
   g_return_val_if_fail (set, FALSE);
-  return (CORBA_boolean)
-    atk_state_set_contains_state (set, atk_state_types[state]);
+  return atk_state_set_contains_state (set, atk_state_types[state]);
 }
 
 
@@ -216,8 +219,7 @@ impl_equals (PortableServer_Servant servant,
   g_object_unref (G_OBJECT(set2));
   if (return_set)
     {
-      rv = (CORBA_boolean)
-	atk_state_set_is_empty (return_set);
+      rv = atk_state_set_is_empty (return_set);
       g_object_unref (G_OBJECT(return_set));
     }
   else
@@ -256,8 +258,7 @@ impl_isEmpty (PortableServer_Servant servant,
   AtkStateSet *set = atk_state_set_from_servant (servant);
 
   g_return_val_if_fail (set, TRUE);
-  return (CORBA_boolean)
-    atk_state_set_is_empty (set);
+  return atk_state_set_is_empty (set);
 }
 
 
@@ -332,6 +333,8 @@ impl_getStates (PortableServer_Servant servant,
     states = g_slist_append (states, (gpointer) Accessibility_STATE_VERTICAL);
   if (atk_state_set_contains_state (set, ATK_STATE_VISIBLE))
     states = g_slist_append (states, (gpointer) Accessibility_STATE_VISIBLE);
+  if (atk_state_set_contains_state (set, ATK_STATE_MANAGES_DESCENDANTS))
+    states = g_slist_append (states, (gpointer) Accessibility_STATE_MANAGES_DESCENDANTS);
 
   rv = Accessibility_StateSeq__alloc ();
   rv->_length = rv->_maximum = g_slist_length (states);
